
/*
 * Copyright (c) Abraham vd Merwe <abz@blio.net>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <limits.h>

#include "typedefs.h"

/*
 * Initialize random number generator
 */
void rand_init ()
{
#ifdef USE_RAND
   srand (time (NULL));
#else
   srandom (time (NULL));
#endif
}

/*
 * Generate a random number within range
 */
int rand_value (int range)
{
#ifdef USE_RAND
   return ((int) ((float) range * rand () / (RAND_MAX + 1.0)));
#else
   return (random () % range);
#endif
}

/*
 * Convert an str to long. Returns TRUE if successful,
 * FALSE otherwise.
 */
bool str2int (int *i,const char *str)
{
   char *endptr;
   *i = strtol (str,&endptr,0);
   if (*str == '\0' || *endptr != '\0' || *i == LONG_MIN || *i == LONG_MAX || *i < INT_MIN || *i > INT_MAX) return FALSE;
   return TRUE;
}

/*
 * Get the scorefile path. Returns the path to the scorefile or NULL
 * on error.
 */
char* get_scorefile_path (void)
{
   char *env_xdg_data_home;
   char *env_home;
   char *xdg_data_home;
   char *scorefile_path;

   env_xdg_data_home = getenv ("XDG_DATA_HOME");
   if (env_xdg_data_home != NULL)
	 {
		xdg_data_home = malloc (strlen (env_xdg_data_home) + 1);
		strcpy (xdg_data_home, env_xdg_data_home);
	 }
   else
	 {
		env_home = getenv ("HOME");
		if (env_home == NULL) return NULL;

		xdg_data_home = malloc (strlen (env_home) + strlen ("/.local/share") + 1);
		if (xdg_data_home == NULL) return NULL;
		strcpy (xdg_data_home,env_home);
		strcat (xdg_data_home,"/.local/share");
	 }

   scorefile_path = malloc (strlen (xdg_data_home) + strlen ("/tint") + 1);
   if (scorefile_path != NULL)
	 {
		strcpy (scorefile_path,xdg_data_home);
		strcat (scorefile_path,"/tint");
	 }
   free (xdg_data_home);

   return scorefile_path;
}

